@@ -128,6 +128,8 @@ class AnalyzeClassifier(AnalyzeModel):
         excluded_columns: Optional[List[str]] = None,
         *,
         wait_until_complete: bool = True,
+        # Classification specific fit parameters
+        sample_weight: Optional[str] = None,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using random data partitioning"""
         ...
@@ -141,6 +143,7 @@ class AnalyzeClassifier(AnalyzeModel):
         *,
         wait_until_complete: bool = True,
         # Classification specific fit parameters
+        sample_weight: Optional[str] = None,
         order_by: str,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using ordered data partitioning"""
@@ -156,6 +159,7 @@ class AnalyzeClassifier(AnalyzeModel):
         wait_until_complete: bool = True,
         # Classification specific fit parameters
         partition_by: str,
+        sample_weight: Optional[str] = None,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using manual data partitioning"""
         ...
@@ -169,6 +173,7 @@ class AnalyzeClassifier(AnalyzeModel):
         *,
         wait_until_complete: bool = True,
         # Classification specific fit parameters
+        sample_weight: Optional[str] = None,
         no_mixing: List[str],
     ) -> "AnalyzeClassifier":
         """Fit the classification model using a no-mixing column data partitioning"""
@@ -181,7 +186,8 @@ class AnalyzeClassifier(AnalyzeModel):
         excluded_columns: Optional[List[str]] = None,
         *,
         wait_until_complete: bool = True,
-        # Regression specific fit parameters
+        # Classification specific fit parameters
+        sample_weight: Optional[str] = None,
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
         no_mixing: Optional[List[str]] = None,
@@ -195,5 +201,6 @@ class AnalyzeClassifier(AnalyzeModel):
             order_by=order_by,
             partition_by=partition_by,
             no_mixing=no_mixing,
+            sample_weight=sample_weight,
         )
         return self
