@@ -28,6 +28,7 @@ class CreateClassificationRequest:
     no_mixing_columns: Union[Unset, List[str]] = UNSET
     partition_column: Union[Unset, str] = UNSET
     order_by_column: Union[Unset, str] = UNSET
+    weight_column: Union[Unset, str] = UNSET
     model_types: Union[Unset, List[ClassificationModelType]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -65,6 +66,7 @@ class CreateClassificationRequest:
 
         partition_column =  self.partition_column
         order_by_column =  self.order_by_column
+        weight_column =  self.weight_column
         model_types: Union[Unset, List[Any]] = UNSET
         if not isinstance(self.model_types, Unset):
             model_types = []
@@ -102,6 +104,8 @@ class CreateClassificationRequest:
             field_dict["partitionColumn"] = partition_column
         if order_by_column is not UNSET:
             field_dict["orderByColumn"] = order_by_column
+        if weight_column is not UNSET:
+            field_dict["weightColumn"] = weight_column
         if model_types is not UNSET:
             field_dict["modelTypes"] = model_types
 
@@ -155,6 +159,8 @@ class CreateClassificationRequest:
 
         order_by_column = d.pop("orderByColumn", UNSET)
 
+        weight_column = d.pop("weightColumn", UNSET)
+
         model_types = []
         _model_types = d.pop("modelTypes", UNSET)
         for model_types_item_data in (_model_types or []):
@@ -180,6 +186,7 @@ class CreateClassificationRequest:
             no_mixing_columns=no_mixing_columns,
             partition_column=partition_column,
             order_by_column=order_by_column,
+            weight_column=weight_column,
             model_types=model_types,
         )
 
